__version__ = "1.0.14"
__author__ = "Job Snijders"
__author_email__ = "job@instituut.net"
__copyright__ = "Copyright 2014-2024, Job Snijders"
__license__ = "BSD 2-Clause"
__status__ = "Development"
__url__ = "https://github.com/job/aggregate6"

from .aggregate6 import aggregate
